import logging
from abc import abstractmethod, ABC
from typing import Dict, Any

logger = logging.getLogger(__name__)


class ConfigStore(ABC):

    @abstractmethod
    def load_data(self) -> None:
        """
        Load the data from the persistent storage.
        """
        ...

    @abstractmethod
    def save_data(self) -> None:
        """
        Store the data to the persistent storage we read it from.
        """
        ...

    @abstractmethod
    def empty(self) -> bool:
        """
        :return: if the configuration is completely empty.
        """
        ...

    @abstractmethod
    def save_raw_and_reload(self, raw_data: Any) -> None:
        """
        :param raw_data:
        """
        ...

    @abstractmethod
    def get(self, name: str, default: Any = None):
        ...

    @abstractmethod
    def get_data(self) -> Dict:
        """
        :return: copy of the data, changes have no side effect.
        """
        ...

    @abstractmethod
    def put(self, name: str, data: Any) -> None:
        ...

    @abstractmethod
    def put_data(self, data: Any) -> None:
        ...
